@@ -72,9 +72,9 @@ KChatBaseModel* KChatBase::model()
 
 KChatBase::KChatBase(QWidget* parent, KChatBaseModel* model, KChatBaseItemDelegate* delegate, bool noComboBox) : QFrame(parent)
 {
-  QLoggingCategory::setFilterRules(QLatin1Literal("games.lib.debug = true"));
-  QLoggingCategory::setFilterRules(QLatin1Literal("games.private.kgame.debug = true"));
-  QLoggingCategory::setFilterRules(QLatin1Literal("games.backgammon.debug = true"));
+  QLoggingCategory::setFilterRules(QStringLiteral("games.lib.debug = true"));
+  QLoggingCategory::setFilterRules(QStringLiteral("games.private.kgame.debug = true"));
+  QLoggingCategory::setFilterRules(QStringLiteral("games.backgammon.debug = true"));
   
   KChatBaseModel* mod = model;
   if (mod==0)
